#include <stdio.h>
#include "hellofunc.h"
#include <YggInterface.h>

int main() {
  sleep(1);
  myPrint("GCC Model");
  return 0;
}
